@@ -26,7 +26,7 @@ int XmysqlDB(int dbaction, int results_to_file)
   unsigned long rows_affected = 0;
   char *semicolon = 0;
   char *pos = 0, *r, *r_end;
-  uint *lengths = 0;
+  ulong *lengths = 0;
   int total_lines = 0;
   int maxSize = 0;
   int maxLen = 0;
@@ -76,13 +76,24 @@ int XmysqlDB(int dbaction, int results_to_file)
     RETURN(TRUE);
   }
 #else
+#if MYSQL_VERSION_ID < 32200
   if (!(sock = mysql_real_connect(&mysql, CURRENT_SERVER, 
 			     (char*)user, 
 			     (char*)pass,
-				  port,
-				  isocket, 0))) {
-    sprintf(dataLine, "Host: %s, Port: %d, Socket: %s",
-	    CURRENT_SERVER, port, isocket);
+				   port,
+				   isocket, 0))) 
+#else
+	mysql_init(&mysql);
+	if (!(sock = mysql_real_connect(&mysql, CURRENT_SERVER, 
+					  (char*)user, 
+						(char*)pass,
+						(char*)0,  /* No database */
+						port,
+						isocket, 0)))
+#endif
+	{
+		sprintf(dataLine, "Host: %s, Port: %d, Socket: %s\nError: '%s'",
+					    CURRENT_SERVER, port, isocket, mysql_error(&mysql));
     XmysqlErr("ALERT",
 	      "ERROR: Can't connect to MySQL Server:",
 	      dataLine,
@@ -408,10 +419,13 @@ int XmysqlDB(int dbaction, int results_to_file)
 	    break;
 
 	  case FIELD_TYPE_DECIMAL:
-          case FIELD_TYPE_SHORT:
+    case FIELD_TYPE_SHORT:
 	  case FIELD_TYPE_LONG:
-          case FIELD_TYPE_LONGLONG:
+    case FIELD_TYPE_LONGLONG:
 	  case FIELD_TYPE_INT24:
+#if MYSQL_VERSION_ID >= 3220
+	  case FIELD_TYPE_YEAR:
+#endif
 	    strcat(browserStr, sqlStr);
 	    break;
 
@@ -428,13 +442,18 @@ int XmysqlDB(int dbaction, int results_to_file)
 	    break;
 
 	  case FIELD_TYPE_DATE:
+#if MYSQL_VERSION_ID >= 32200
+    case FIELD_TYPE_NEWDATE:
+#endif
 	    strcat(browserStr, "\"");
 	    strcat(browserStr, sqlStr);
 	    strcat(browserStr, "\"");
 	    break;
 
 	  case FIELD_TYPE_TIMESTAMP:
+#if MYSQL_VERSION_ID >= 32200
 	  case FIELD_TYPE_DATETIME:
+#endif
 	    strcat(browserStr, "\"");
 	    strcat(browserStr, sqlStr);
 	    strcat(browserStr, "\"");
@@ -529,10 +548,13 @@ int XmysqlDB(int dbaction, int results_to_file)
 	    break;
 	
 	  case FIELD_TYPE_DECIMAL:
-          case FIELD_TYPE_SHORT:
+    case FIELD_TYPE_SHORT:
 	  case FIELD_TYPE_LONG:
-          case FIELD_TYPE_LONGLONG:
+    case FIELD_TYPE_LONGLONG:
 	  case FIELD_TYPE_INT24:
+#if MYSQL_VERSION_ID >= 3220
+	  case FIELD_TYPE_YEAR:
+#endif
 	    strcat(browserStr, sqlStr);
 	    break;
 
@@ -549,6 +571,9 @@ int XmysqlDB(int dbaction, int results_to_file)
 	    break;
 
 	  case FIELD_TYPE_DATE:
+#if MYSQL_VERSION_ID >= 32200
+    case FIELD_TYPE_NEWDATE:
+#endif
 	    strcat(browserStr, "\"");
 	    strcat(browserStr, sqlStr);
 	    strcat(browserStr, "\"");
@@ -764,8 +789,12 @@ int XmysqlDB(int dbaction, int results_to_file)
             if (data->fields[x].max_length > 0 &&
 				  data->fields[x].max_length > 4)
 		  			pos=strfill(pos, data->fields[x].max_length - 4,' ');
-            else
-               pos=strfill(pos, strlen(data->fields[x].name) - 4,' ');
+            else {
+				   if (strlen(data->fields[x].name) >= 4)
+                 pos=strfill(pos, strlen(data->fields[x].name) - 4,' ');
+               else           
+                 pos=strfill(pos, 4 - strlen(data->fields[x].name),' ');
+			   }
 	      }
 
 	      if ((x+1) < cols)
